<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Validator;

class FetchController extends Controller
{
    public function getData(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'url' => 'required|url',
        ]);

        if ($validator->fails()) {
            return response()->json($validator->errors(), 400);
        }

        $menuUrl = $request->query('url'); // Get URL from query parameter

        try {
            $response = Http::get($menuUrl); // Fetch data from third-party server

            if ($response->successful()) {
                return response($response->body(), $response->status())
                    ->header('Content-Type', 'application/json');
            } else {
                return response()->json(['error' => 'Failed to fetch data'], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }
}